! source file: /usr/local/models/UVic_ESCM/2.8/source/common/eoyr.F

      subroutine eoyr (is, ie, js, je)
!=======================================================================
!     things to do at the end of a year

!     input:
!       is, ie, js, je = starting and ending indicies for i and j

!     based on code by: M. Eby
!=======================================================================

      implicit none

      include "param.h"
      include "calendar.h"
      include "csbc.h"
      include "levind.h"
      include "atm.h"
      include "coord.h"
      include "grdvar.h"
      include "cembm.h"
      include "iounit.h"
      include "scalar.h"
      include "switch.h"
      include "tmngr.h"

      include "ice.h"

      include "mtlm.h"

      character(120) :: fname, new_file_name
      character(3) :: a3

      integer i, ie, is, iou, j, je, js, L, ib(10), ic(10), n

      logical exists, inqvardef

      real wt, f, dmsk(imt,jmt)

      return
      end
